==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/zh-CN/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>帐户</strong> 注册',
    '<strong>Change</strong> your password' => '<strong>修改</strong> 你的密码',
    '<strong>Join</strong> the network' => '<strong>加入</strong> 社交平台',
    '<strong>Password</strong> changed!' => '<strong>密码</strong> 已修改!',
    '<strong>Password</strong> recovery' => '<strong>找回</strong> 密码',
    '<strong>Password</strong> recovery!' => '<strong>找回</strong> 密码!',
    '<strong>Please</strong> sign in' => '<strong>请</strong> 登录',
    '<strong>Registration</strong> successful!' => '<strong>注册</strong> 成功!',
    '<strong>Sign</strong> up' => '注册',
    '<strong>Your account</strong> has been successfully created!' => '<strong>你的帐户</strong> 已被成功创建!',
    'Account' => '帐号',
    'After activating your account by the administrator, you will receive a notification by email.' => '为了激活你的帐户，你将出到一个邮件通知！',
    'Back' => '返回',
    'Change password' => '修改密码',
    'Confirm' => '确认',
    'Create Account' => '创建帐户',
    'Create account' => '创建帐号',
    'Don\'t have an account? Join the network by entering your e-mail address.' => '你还没有帐号？通过输入电子邮箱加入我们。',
    'Enter security code above' => '输入上面的安全码',
    'Forgot your password?' => '忘记你的密码？',
    'Go to login page' => '去登录页',
    'Group' => '用户组',
    'Hello {displayName}' => '你好 {displayName}',
    'Hello {displayName},' => '你好{displayName} ，',
    'If you don\'t use this link within 24 hours, it will expire.' => '如果你不在24小时内使用这个链接，它会自动过期',
    'If you\'re already a member, please login with your username/email and password.' => '如果你已经是会员，请登录',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => '输入你的邮箱。我们会发送找回密码的指令链接给你！',
    'Login' => '登录',
    'New user needs approval' => '新用户需要审核',
    'Password' => '密码',
    'Password recovery' => '找回密码',
    'Password reset' => '重置密码',
    'Please check your email and follow the instructions!' => '请检查邮件完成激活',
    'Please use the following link within the next day to reset your password.' => '请在24小时内使用以下链接来重新设置您的密码。',
    'Register' => '注册',
    'Registration successful' => '注册成功',
    'Remember me' => '记住密码',
    'Reset Password' => '重置密码',
    'Reset password' => '重置密码',
    'Sign in' => '登录',
    'To log in with your new account, click the button below.' => '登录您的新帐户，请单击下面的按钮',
    'Username or Email' => '用户名或邮箱',
    'Your email' => '你的邮箱',
    'Your password' => '你的密码',
    'Your password has been successfully changed!' => '你的密码已被成功修改！',
    'Your password is incorrect!' => '密码不正确',
    'back to home' => '返回主页',
    '<strong>Change</strong> Password' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'Log out' => '',
    'Please click on the link below to view request:' => '',
    'Please enter the letters from the image.' => '',
    'Please login with your username/email and password.' => '',
    'Please wait' => '',
    'User or Password incorrect.' => '',
    'a new user {displayName} needs approval.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/zh-CN/auth.php <==
<?php

return [
    '<strong>Account</strong> registration' => '<strong>帐户</strong> 注册',
    '<strong>Change</strong> your password' => '<strong>修改</strong> 你的密码',
    '<strong>Join</strong> the network' => '<strong>加入</strong> 社交平台',
    '<strong>Password</strong> changed!' => '<strong>密码</strong> 已修改!',
    '<strong>Password</strong> recovery' => '<strong>找回</strong> 密码',
    '<strong>Password</strong> recovery!' => '<strong>找回</strong> 密码!',
    '<strong>Please</strong> sign in' => '<strong>请</strong> 登录',
    '<strong>Registration</strong> successful!' => '<strong>注册</strong> 成功!',
    '<strong>Sign</strong> up' => '注册',
    '<strong>Your account</strong> has been successfully created!' => '<strong>你的帐户</strong> 已被成功创建!',
    'Account' => '帐号',
    'After activating your account by the administrator, you will receive a notification by email.' => '为了激活你的帐户，你将出到一个邮件通知！',
    'Back' => '返回',
    'Change password' => '修改密码',
    'Confirm' => '确认',
    'Create Account' => '创建帐户',
    'Create account' => '创建帐号',
    'Don\'t have an account? Join the network by entering your e-mail address.' => '你还没有帐号？通过输入电子邮箱加入我们。',
    'Forgot your password?' => '忘记你的密码？',
    'Go to login page' => '去登录页',
    'Group' => '用户组',
    'Hello {displayName}' => '你好 {displayName}',
    'Hello {displayName},' => '你好{displayName} ，',
    'If you don\'t use this link within 24 hours, it will expire.' => '如果你不在24小时内使用这个链接，它会自动过期',
    'If you\'re already a member, please login with your username/email and password.' => '如果你已经是会员，请登录',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => '输入你的邮箱。我们会发送找回密码的指令链接给你！',
    'Login' => '登录',
    'New user needs approval' => '新用户需要审核',
    'Password' => '密码',
    'Password recovery' => '找回密码',
    'Password reset' => '重置密码',
    'Please use the following link within the next day to reset your password.' => '请在24小时内使用以下链接来重新设置您的密码。',
    'Register' => '注册',
    'Remember me' => '记住密码',
    'Reset Password' => '重置密码',
    'Reset password' => '重置密码',
    'Sign in' => '登录',
    'To log in with your new account, click the button below.' => '登录您的新帐户，请单击下面的按钮',
    'Username or Email' => '用户名或邮箱',
    'Your email' => '你的邮箱',
    'Your password' => '你的密码',
    'Your password has been successfully changed!' => '你的密码已被成功修改！',
    'Your password is incorrect!' => '密码不正确',
    '<strong>Change</strong> Password' => '',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
    'Log out' => '',
    'Please click on the link below to view request:' => '',
    'Please login with your username/email and password.' => '',
    'Please wait' => '',
    'User or Password incorrect.' => '',
    'a new user {displayName} needs approval.' => '',
];
